@@ -1,11 +1,11 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: document builder role
 package PONAPI::Builder;
 
 use Moose::Role;
 
 requires 'build';
 
-has 'parent' => (
+has parent => (
     is        => 'ro',
     does      => 'PONAPI::Builder',
     predicate => 'has_parent',
@@ -62,19 +62,33 @@ __END__
 
 =head1 NAME
 
-PONAPI::Builder - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+PONAPI::Builder - document builder role
 
 =head1 VERSION
 
-version 0.001001
+version 0.001003
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Mickey Nasriachi <mickey@cpan.org>
 
+=item *
+
+Stevan Little <stevan@cpan.org>
+
+=item *
+
+Brian Fraser <hugmeir@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Mickey Nasriachi, Stevan Little, Brian Fraser.
+This software is copyright (c) 2016 by Mickey Nasriachi, Stevan Little, Brian Fraser.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
