@@ -1,11 +1,11 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: document builder - errors
 package PONAPI::Builder::Errors;
 
 use Moose;
 
 with 'PONAPI::Builder';
 
-has '_errors' => (
+has _errors => (
     init_arg => undef,
     traits   => [ 'Array' ],
     is       => 'ro',
@@ -20,17 +20,13 @@ has '_errors' => (
 );
 
 sub add_error {
-    my $self  = $_[0];
-    my $error = $_[1];
-
+    my ( $self, $error ) = @_;
     $self->_add_error( $error );
 }
 
 sub build {
-    my $self   = $_[0];
-    my $result = [];
-    @$result = @{ $self->_errors };
-    return $result;
+    my $self = $_[0];
+    return +[ @{ $self->_errors } ];
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -44,19 +40,33 @@ __END__
 
 =head1 NAME
 
-PONAPI::Builder::Errors - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+PONAPI::Builder::Errors - document builder - errors
 
 =head1 VERSION
 
-version 0.001001
+version 0.001003
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Mickey Nasriachi <mickey@cpan.org>
 
+=item *
+
+Stevan Little <stevan@cpan.org>
+
+=item *
+
+Brian Fraser <hugmeir@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Mickey Nasriachi, Stevan Little, Brian Fraser.
+This software is copyright (c) 2016 by Mickey Nasriachi, Stevan Little, Brian Fraser.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
