@@ -1,4 +1,4 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: document builder - relationship
 package PONAPI::Builder::Relationship;
 
 use Moose;
@@ -15,7 +15,7 @@ has name => (
     required => 1,
 );
 
-has '_resource_id_builders' => (
+has _resource_id_builders => (
     init_arg  => undef,
     traits    => [ 'Array' ],
     is        => 'ro',
@@ -31,9 +31,9 @@ has '_resource_id_builders' => (
     }
 );
 
-has 'collection' => (
-    is       => 'ro',
-    isa      => 'Bool',
+has collection => (
+    is  => 'ro',
+    isa => 'Bool',
 );
 
 sub has_resource {
@@ -47,7 +47,7 @@ sub has_resources {
 }
 
 sub add_resource {
-    my ($self, $resource) = @_;
+    my ( $self, $resource ) = @_;
     my $b = PONAPI::Builder::Resource::Identifier->new( parent => $self, %$resource );
     $b->add_meta( %{ $resource->{meta} } ) if $resource->{meta};
     $self->_add_resource_id_builder( $b );
@@ -103,19 +103,33 @@ __END__
 
 =head1 NAME
 
-PONAPI::Builder::Relationship - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+PONAPI::Builder::Relationship - document builder - relationship
 
 =head1 VERSION
 
-version 0.001001
+version 0.001003
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Mickey Nasriachi <mickey@cpan.org>
 
+=item *
+
+Stevan Little <stevan@cpan.org>
+
+=item *
+
+Brian Fraser <hugmeir@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Mickey Nasriachi, Stevan Little, Brian Fraser.
+This software is copyright (c) 2016 by Mickey Nasriachi, Stevan Little, Brian Fraser.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
