@@ -1,4 +1,4 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: document builder - resource identifier
 package PONAPI::Builder::Resource::Identifier;
 
 use Moose;
@@ -6,8 +6,8 @@ use Moose;
 with 'PONAPI::Builder',
      'PONAPI::Builder::Role::HasMeta';
 
-has 'id'   => ( is => 'ro', isa => 'Str', required => 1 );
-has 'type' => ( is => 'ro', isa => 'Str', required => 1 );
+has id   => ( is => 'ro', isa => 'Str', required => 1 );
+has type => ( is => 'ro', isa => 'Str', required => 1 );
 
 sub build {
     my $self   = $_[0];
@@ -31,19 +31,33 @@ __END__
 
 =head1 NAME
 
-PONAPI::Builder::Resource::Identifier - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+PONAPI::Builder::Resource::Identifier - document builder - resource identifier
 
 =head1 VERSION
 
-version 0.001002
+version 0.001003
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Mickey Nasriachi <mickey@cpan.org>
 
+=item *
+
+Stevan Little <stevan@cpan.org>
+
+=item *
+
+Brian Fraser <hugmeir@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Mickey Nasriachi, Stevan Little, Brian Fraser.
+This software is copyright (c) 2016 by Mickey Nasriachi, Stevan Little, Brian Fraser.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
