@@ -1,4 +1,4 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: document builder - role - links
 package PONAPI::Builder::Role::HasLinksBuilder;
 
 use Moose::Role;
@@ -7,7 +7,7 @@ use PONAPI::Builder::Links;
 
 requires 'add_self_link';
 
-has 'links_builder' => (
+has links_builder => (
     init_arg  => undef,
     is        => 'ro',
     isa       => 'PONAPI::Builder::Links',
@@ -51,19 +51,33 @@ __END__
 
 =head1 NAME
 
-PONAPI::Builder::Role::HasLinksBuilder - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+PONAPI::Builder::Role::HasLinksBuilder - document builder - role - links
 
 =head1 VERSION
 
-version 0.001002
+version 0.001003
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Mickey Nasriachi <mickey@cpan.org>
 
+=item *
+
+Stevan Little <stevan@cpan.org>
+
+=item *
+
+Brian Fraser <hugmeir@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Mickey Nasriachi, Stevan Little, Brian Fraser.
+This software is copyright (c) 2016 by Mickey Nasriachi, Stevan Little, Brian Fraser.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
