@@ -1,4 +1,4 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: Data Abstraction Object class
 package PONAPI::DAO;
 
 use Moose;
@@ -56,6 +56,7 @@ sub _action {
     my @ret;
     eval {
         @ret = $action_class->new($ponapi_parameters)->execute();
+        1;
     } or do {
         my $e = $@ || 'Unknown error';
         @ret = PONAPI::DAO::Exception
@@ -77,11 +78,11 @@ __END__
 
 =head1 NAME
 
-PONAPI::DAO - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+PONAPI::DAO - Data Abstraction Object class
 
 =head1 VERSION
 
-version 0.001001
+version 0.001003
 
 =head1 SYNOPSIS
 
@@ -181,10 +182,6 @@ plain hashrefs, and they B<must> include both a C<type> and C<id>; they
 may also contain additional keys.  See L<http://jsonapi.org/format/#document-resource-objects>
 for a more in-depth description.
 
-=head1 NAME
-
-PONAPI::DAO - Interface to a JSON API.
-
 =head1 METHODS
 
 =head2 new
@@ -203,7 +200,7 @@ it in the response.
 By default, C<PONAPI::DAO> will simply turn those C<200 OK> into
 C<202 Accepted>, avoiding the need to do the extra fetch.  If needed, the
 full 200 responses can be re-enabled by passing
-C<respond_to_updates_with_200 => 1,> to C<new>.
+C<respond_to_updates_with_200 =E<gt> 1,> to C<new>.
 
 =head1 API METHODS
 
@@ -455,8 +452,8 @@ Meanwhile, if the update was successful but more data than requested was
 updated -- Consider C<updated-at> columns in a table -- then the request
 will return both a top-level C<meta> key, and a top-level C<data> key,
 containing the results of a C<retrieve> operation on the primary updated
-resource.  Since this behavior can be undesirable, unless C<PONAPI::DAO->new>
-was passed C<respond_to_updates_with_200 => 1>, this sort of response is
+resource.  Since this behavior can be undesirable, unless C<PONAPI::DAO-E<gt>new>
+was passed C<respond_to_updates_with_200 =E<gt> 1>, this sort of response is
 disabled, and the server will instead respond with a L</"202 Accepted">,
 described below.
 
@@ -554,13 +551,27 @@ Adds a new member to the specified one-to-many relationship.
 
 See also L</"Return value of update operations">.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Mickey Nasriachi <mickey@cpan.org>
 
+=item *
+
+Stevan Little <stevan@cpan.org>
+
+=item *
+
+Brian Fraser <hugmeir@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Mickey Nasriachi, Stevan Little, Brian Fraser.
+This software is copyright (c) 2016 by Mickey Nasriachi, Stevan Little, Brian Fraser.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
