@@ -1,4 +1,4 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: Constants used by PONAPI::DAO and PONAPI repositories
 package PONAPI::DAO::Constants;
 
 my $constants;
@@ -34,11 +34,11 @@ __END__
 
 =head1 NAME
 
-PONAPI::DAO::Constants - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+PONAPI::DAO::Constants - Constants used by PONAPI::DAO and PONAPI repositories
 
 =head1 VERSION
 
-version 0.001001
+version 0.001003
 
 =head1 SYNOPSIS
 
@@ -51,10 +51,6 @@ version 0.001001
                : PONAPI_UPDATED_NORMAL;
     }
 
-=head1 NAME
-
-PONAPI::DAO::Constants - Constants used by PONAPI::DAO and PONAPI repositories
-
 =head1 EXPORTS
 
 =head2 PONAPI_UPDATED_NORMAL
@@ -71,13 +67,27 @@ or updated another related table.
 The update-like operation was a no-op.  This can happen in a SQL implementation
 when modifying a resource that doesn't exist, for example.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Mickey Nasriachi <mickey@cpan.org>
 
+=item *
+
+Stevan Little <stevan@cpan.org>
+
+=item *
+
+Brian Fraser <hugmeir@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Mickey Nasriachi, Stevan Little, Brian Fraser.
+This software is copyright (c) 2016 by Mickey Nasriachi, Stevan Little, Brian Fraser.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
