@@ -1,4 +1,4 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: DAO request class
 package PONAPI::DAO::Request;
 
 use Moose;
@@ -142,7 +142,15 @@ sub response {
     $doc->add_self_link
         if $self->send_doc_self_link && !$doc->has_link('self');
 
-    return ( $doc->status, \@headers, $doc->build );
+    return (
+        $doc->status,
+        \@headers,
+        (
+            $doc->status != 204
+                ? $doc->build
+                : ()
+        ),
+    );
 }
 
 sub _bad_request {
@@ -163,19 +171,33 @@ __END__
 
 =head1 NAME
 
-PONAPI::DAO::Request - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+PONAPI::DAO::Request - DAO request class
 
 =head1 VERSION
 
-version 0.001002
+version 0.001003
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Mickey Nasriachi <mickey@cpan.org>
 
+=item *
+
+Stevan Little <stevan@cpan.org>
+
+=item *
+
+Brian Fraser <hugmeir@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Mickey Nasriachi, Stevan Little, Brian Fraser.
+This software is copyright (c) 2016 by Mickey Nasriachi, Stevan Little, Brian Fraser.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
