@@ -1,4 +1,4 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: DAO request - create relationships
 package PONAPI::DAO::Request::CreateRelationships;
 
 use Moose;
@@ -22,16 +22,9 @@ sub execute {
     my $self = shift;
 
     if ( $self->is_valid ) {
-        local $@;
-        eval {
-            my @ret = $self->repository->create_relationships( %{ $self } );
-            $self->_add_success_meta(@ret)
-                if $self->_verify_update_response(@ret);
-            1;
-        } or do {
-            my $e = $@;
-            $self->_handle_error($e);
-        };
+        my @ret = $self->repository->create_relationships( %{ $self } );
+        $self->_add_success_meta(@ret)
+            if $self->_verify_update_response(@ret);
     }
 
     return $self->response();
@@ -61,19 +54,33 @@ __END__
 
 =head1 NAME
 
-PONAPI::DAO::Request::CreateRelationships - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+PONAPI::DAO::Request::CreateRelationships - DAO request - create relationships
 
 =head1 VERSION
 
-version 0.001001
+version 0.001003
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Mickey Nasriachi <mickey@cpan.org>
 
+=item *
+
+Stevan Little <stevan@cpan.org>
+
+=item *
+
+Brian Fraser <hugmeir@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Mickey Nasriachi, Stevan Little, Brian Fraser.
+This software is copyright (c) 2016 by Mickey Nasriachi, Stevan Little, Brian Fraser.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
