@@ -1,4 +1,4 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: DAO request - retrieve
 package PONAPI::DAO::Request::Retrieve;
 
 use Moose;
@@ -20,7 +20,7 @@ sub execute {
     if ( $self->is_valid ) {
         $self->repository->retrieve( %{ $self } );
         $self->document->add_null_resource
-            unless $self->document->_has_resource_builders;
+            unless $self->document->has_resource_builders;
     }
 
     return $self->response();
@@ -37,19 +37,33 @@ __END__
 
 =head1 NAME
 
-PONAPI::DAO::Request::Retrieve - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+PONAPI::DAO::Request::Retrieve - DAO request - retrieve
 
 =head1 VERSION
 
-version 0.001002
+version 0.001003
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Mickey Nasriachi <mickey@cpan.org>
 
+=item *
+
+Stevan Little <stevan@cpan.org>
+
+=item *
+
+Brian Fraser <hugmeir@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Mickey Nasriachi, Stevan Little, Brian Fraser.
+This software is copyright (c) 2016 by Mickey Nasriachi, Stevan Little, Brian Fraser.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
