@@ -1,4 +1,4 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: DAO request - retrieve relationships
 package PONAPI::DAO::Request::RetrieveRelationships;
 
 use Moose;
@@ -24,7 +24,7 @@ sub execute {
         $repo->retrieve_relationships( %{ $self } );
 
         $document->add_null_resource
-            unless $one_to_many or $document->_has_resource_builders;
+            unless $one_to_many or $document->has_resource_builders;
     }
 
     return $self->response();
@@ -41,19 +41,33 @@ __END__
 
 =head1 NAME
 
-PONAPI::DAO::Request::RetrieveRelationships - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+PONAPI::DAO::Request::RetrieveRelationships - DAO request - retrieve relationships
 
 =head1 VERSION
 
-version 0.001002
+version 0.001003
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Mickey Nasriachi <mickey@cpan.org>
 
+=item *
+
+Stevan Little <stevan@cpan.org>
+
+=item *
+
+Brian Fraser <hugmeir@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Mickey Nasriachi, Stevan Little, Brian Fraser.
+This software is copyright (c) 2016 by Mickey Nasriachi, Stevan Little, Brian Fraser.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
