@@ -1,4 +1,4 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: DAO request role - `update` & like related functionality
 package PONAPI::DAO::Request::Role::UpdateLike;
 
 use Moose::Role;
@@ -6,12 +6,12 @@ use Moose::Role;
 use PONAPI::DAO::Constants;
 use PONAPI::DAO::Exception;
 
-has 'respond_to_updates_with_200' => (
+has respond_to_updates_with_200 => (
     is  => 'ro',
     isa => 'Bool',
 );
 
-has 'update_nothing_status' => (
+has update_nothing_status => (
     is      => 'ro',
     isa     => 'Int',
     # http://jsonapi.org/format/#crud-updating-relationship-responses-204
@@ -25,7 +25,8 @@ sub _verify_update_response {
     my ( $self, $ret, @extra ) = @_;
 
     PONAPI::DAO::Exception->throw(
-        internal => "update-like operation returned an unexpected value"
+        internal => 1,
+        message  => "update-like operation returned an unexpected value"
     ) unless exists $PONAPI_UPDATE_RETURN_VALUES{$ret};
 
     my $doc = $self->document;
@@ -56,6 +57,10 @@ sub _add_success_meta {
     if ( $return_status == PONAPI_UPDATED_NOTHING ) {
         my $status = $self->update_nothing_status;
         $self->document->set_status($status);
+        # This should NEVER show up in a response, because it would
+        # mean a 204 with a body; I'm still leaving it here because
+        # a 204+body is preferable to a server error due to an empty
+        # document.
         $detail = "modified nothing for $resource"
     }
 
@@ -82,19 +87,33 @@ __END__
 
 =head1 NAME
 
-PONAPI::DAO::Request::Role::UpdateLike - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+PONAPI::DAO::Request::Role::UpdateLike - DAO request role - `update` & like related functionality
 
 =head1 VERSION
 
-version 0.001001
+version 0.001003
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Mickey Nasriachi <mickey@cpan.org>
 
+=item *
+
+Stevan Little <stevan@cpan.org>
+
+=item *
+
+Brian Fraser <hugmeir@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Mickey Nasriachi, Stevan Little, Brian Fraser.
+This software is copyright (c) 2016 by Mickey Nasriachi, Stevan Little, Brian Fraser.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
