@@ -1,4 +1,4 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: DAO request - update relationships
 package PONAPI::DAO::Request::UpdateRelationships;
 
 use Moose;
@@ -21,18 +21,10 @@ sub check_data_type_match { 1 } # to avoid code duplications in HasDataMethods
 sub execute {
     my $self = shift;
     if ( $self->is_valid ) {
-        local $@;
-        eval {
-            my @ret = $self->repository->update_relationships( %{ $self } );
+        my @ret = $self->repository->update_relationships( %{ $self } );
 
-            $self->_add_success_meta(@ret)
-                if $self->_verify_update_response(@ret);
-
-            1;
-        } or do {
-            my $e = $@;
-            $self->_handle_error($e);
-        };
+        $self->_add_success_meta(@ret)
+            if $self->_verify_update_response(@ret);
     }
 
     return $self->response();
@@ -50,19 +42,33 @@ __END__
 
 =head1 NAME
 
-PONAPI::DAO::Request::UpdateRelationships - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+PONAPI::DAO::Request::UpdateRelationships - DAO request - update relationships
 
 =head1 VERSION
 
-version 0.001001
+version 0.001003
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Mickey Nasriachi <mickey@cpan.org>
 
+=item *
+
+Stevan Little <stevan@cpan.org>
+
+=item *
+
+Brian Fraser <hugmeir@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Mickey Nasriachi, Stevan Little, Brian Fraser.
+This software is copyright (c) 2016 by Mickey Nasriachi, Stevan Little, Brian Fraser.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
