@@ -1,10 +1,11 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: Web-Server - configuration handler
 package PONAPI::Server::ConfigReader;
 
 use Moose;
 
 use Moose::Util::TypeConstraints;
 use Path::Class::Dir;
+use YAML::XS ();
 
 use PONAPI::DAO;
 
@@ -120,19 +121,33 @@ __END__
 
 =head1 NAME
 
-PONAPI::Server::ConfigReader - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+PONAPI::Server::ConfigReader - Web-Server - configuration handler
 
 =head1 VERSION
 
-version 0.001001
+version 0.001003
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Mickey Nasriachi <mickey@cpan.org>
 
+=item *
+
+Stevan Little <stevan@cpan.org>
+
+=item *
+
+Brian Fraser <hugmeir@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Mickey Nasriachi, Stevan Little, Brian Fraser.
+This software is copyright (c) 2016 by Mickey Nasriachi, Stevan Little, Brian Fraser.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
