@@ -1,12 +1,14 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: mock repository class
 package Test::PONAPI::DAO::Repository::MockDB;
 
 use Moose;
 
 use DBI;
-use DBD::SQLite::Constants qw/:result_codes/;;
 use SQL::Composer;
-use Scalar::Util qw/looks_like_number/;
+
+# We MUST use DBD::SQLite before ::Constants to get anything useful!
+use DBD::SQLite;
+use DBD::SQLite::Constants qw/:result_codes/;
 
 use Test::PONAPI::DAO::Repository::MockDB::Loader;
 
@@ -184,16 +186,22 @@ sub create {
     my $dbh = $self->dbh;
     $dbh->begin_work;
 
-    local $@;
-    eval {
-        $self->_create(%args);
-        $dbh->commit;
+    my ($e, $failed);
+    {
+        local $@;
+        eval  { $self->_create( %args ); 1; }
+        or do {
+            ($failed, $e) = (1, $@||'Unknown error');
+        };
     }
-    or do {
-        my $e = $@;
+    if ( $failed ) {
         $dbh->rollback;
         die $e;
-    };
+    }
+
+    $dbh->commit;
+
+    return;
 }
 
 sub _create {
@@ -270,11 +278,16 @@ sub _create_relationships {
             values => $values,
         );
 
-        eval  { $self->_db_execute( $stmt ); 1; }
-        or do {
-            my $e = $@;
-            local $@ = $@;
-            if ( $one_to_one && eval { $e->sql_error } ) {
+        my ($failed, $e);
+        {
+            local $@;
+            eval  { $self->_db_execute( $stmt ); 1; }
+            or do {
+                ($failed, $e) = (1, $@||'Unknown error');
+            };
+        }
+        if ( $failed ) {
+            if ( $one_to_one && do { local $@; eval { $e->sql_error } } ) {
                 # Can't quite do ::Upsert
                 $stmt = SQL::Composer::Update->new(
                     table  => $rel_table,
@@ -299,13 +312,18 @@ sub create_relationships {
     my $dbh = $self->dbh;
     $dbh->begin_work;
 
-    my $ret;
-    eval  { $ret = $self->_create_relationships( %args ); 1; }
-    or do {
-        my $e = $@||'Unknown error';
+    my ($ret, $e, $failed);
+    {
+        local $@;
+        eval  { $ret = $self->_create_relationships( %args ); 1; }
+        or do {
+            ($failed, $e) = (1, $@||'Unknown error');
+        };
+    }
+    if ( $failed ) {
         $dbh->rollback;
         die $e;
-    };
+    }
 
     $dbh->commit;
     return $ret;
@@ -318,13 +336,18 @@ sub update {
     my $dbh = $self->dbh;
     $dbh->begin_work;
 
-    my $ret;
-    eval  { $ret = $self->_update( %args ); 1 }
-    or do {
-        my $e = $@;
+    my ($ret, $e, $failed);
+    {
+        local $@;
+        eval  { $ret = $self->_update( %args ); 1 }
+        or do {
+            ($failed, $e) = (1, $@||'Unknown error');
+        };
+    }
+    if ( $failed ) {
         $dbh->rollback;
         die $e;
-    };
+    }
 
     $dbh->commit;
     return $ret;
@@ -425,13 +448,18 @@ sub update_relationships {
     my $dbh = $self->dbh;
     $dbh->begin_work;
 
-    my $ret;
-    eval  { $ret = $self->_update_relationships( %args ); 1 }
-    or do {
-        my $e = $@;
+    my ($ret, $e, $failed);
+    {
+        local $@;
+        eval  { $ret = $self->_update_relationships( %args ); 1 }
+        or do {
+            ($failed, $e) = (1, $@||'Unknown error');
+        };
+    }
+    if ( $failed ) {
         $dbh->rollback;
         die $e;
-    };
+    }
 
     $dbh->commit;
 
@@ -462,16 +490,18 @@ sub delete_relationships {
     my $dbh = $self->dbh;
     $dbh->begin_work;
 
-    my $ret;
-    eval {
-        $ret = $self->_delete_relationships(%args);
-        1;
+    my ($ret, $e, $failed);
+    {
+        local $@;
+        eval  { $ret = $self->_delete_relationships( %args ); 1 }
+        or do {
+            ($failed, $e) = (1, $@||'Unknown error');
+        };
     }
-    or do {
-        my $e = $@;
+    if ( $failed ) {
         $dbh->rollback;
         die $e;
-    };
+    }
 
     $dbh->commit;
 
@@ -593,10 +623,10 @@ sub _validate_page {
     exists $page->{limit}
         or PONAPI::DAO::Exception->throw(message => "Limit missing for `page`");
 
-    looks_like_number($page->{limit})
+    $page->{limit} =~ /\A[0-9]+\z/
         or PONAPI::DAO::Exception->throw(message => "Bad limit value ($page->{limit}) in `page`");
 
-    !exists $page->{offset} || looks_like_number($page->{offset})
+    !exists $page->{offset} || ($page->{offset} =~ /\A[0-9]+\z/)
         or PONAPI::DAO::Exception->throw(message => "Bad offset value in `page`");
 
     $page->{offset} ||= 0;
@@ -729,25 +759,35 @@ sub _fetchall_relationships {
     return \%ret;
 }
 
+# Might not be there?
+my $sqlite_constraint_failed = do {
+    local $@;
+    eval { SQLITE_CONSTRAINT() } // undef;
+};
 sub _db_execute {
     my ( $self, $stmt ) = @_;
 
-    my ($sth, $ret);
-    local $@;
-    eval {
-        $sth = $self->dbh->prepare($stmt->to_sql);
-        $ret = $sth->execute($stmt->to_bind);
-        # This should never happen, since the DB handle is
-        # created with RaiseError.
-        die $DBI::errstr if !$ret;
-        1;
-    } or do {
-        my $e = "$@"||'Unknown error';
-        my $errstr = $DBI::errstr;
-        my $err_id = $DBI::err;
+    my ($sth, $ret, $failed, $e);
+    {
+        local $@;
+        eval {
+            $sth = $self->dbh->prepare($stmt->to_sql);
+            $ret = $sth->execute($stmt->to_bind);
+            # This should never happen, since the DB handle is
+            # created with RaiseError.
+            die $DBI::errstr if !$ret;
+            1;
+        } or do {
+            $failed = 1;
+            $e = $@ || 'Unknown error';
+        };
+    };
+    if ( $failed ) {
+        my $errstr = $DBI::errstr || "Unknown SQL error";
+        my $err_id = $DBI::err    || 0;
 
         my $message;
-        if ( $err_id && $err_id == SQLITE_CONSTRAINT ) {
+        if ( $sqlite_constraint_failed && $err_id && $err_id == $sqlite_constraint_failed ) {
             PONAPI::DAO::Exception->throw(
                 message   => "Table constraint failed: $errstr",
                 sql_error => 1,
@@ -782,19 +822,33 @@ __END__
 
 =head1 NAME
 
-Test::PONAPI::DAO::Repository::MockDB - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+Test::PONAPI::DAO::Repository::MockDB - mock repository class
 
 =head1 VERSION
 
-version 0.001001
+version 0.001003
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Mickey Nasriachi <mickey@cpan.org>
 
+=item *
+
+Stevan Little <stevan@cpan.org>
+
+=item *
+
+Brian Fraser <hugmeir@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Mickey Nasriachi, Stevan Little, Brian Fraser.
+This software is copyright (c) 2016 by Mickey Nasriachi, Stevan Little, Brian Fraser.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
