@@ -1,4 +1,4 @@
-# ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+# ABSTRACT: mock repository - table class
 package Test::PONAPI::DAO::Repository::MockDB::Table;
 
 use Moose;
@@ -149,19 +149,33 @@ __END__
 
 =head1 NAME
 
-Test::PONAPI::DAO::Repository::MockDB::Table - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
+Test::PONAPI::DAO::Repository::MockDB::Table - mock repository - table class
 
 =head1 VERSION
 
-version 0.001002
+version 0.001003
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Mickey Nasriachi <mickey@cpan.org>
 
+=item *
+
+Stevan Little <stevan@cpan.org>
+
+=item *
+
+Brian Fraser <hugmeir@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Mickey Nasriachi, Stevan Little, Brian Fraser.
+This software is copyright (c) 2016 by Mickey Nasriachi, Stevan Little, Brian Fraser.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
